@@ -1,7 +1,7 @@
 package segments
 
 type Flutter struct {
-	language
+	Language
 }
 
 func (f *Flutter) Template() string {
@@ -11,19 +11,20 @@ func (f *Flutter) Template() string {
 func (f *Flutter) Enabled() bool {
 	f.extensions = dartExtensions
 	f.folders = dartFolders
-	f.commands = []*cmd{
-		{
+	f.tooling = map[string]*cmd{
+		"fvm": {
 			executable: "fvm",
 			args:       []string{"flutter", "--version"},
 			regex:      `Flutter (?P<version>((?P<major>[0-9]+).(?P<minor>[0-9]+).(?P<patch>[0-9]+)))`,
 		},
-		{
+		"flutter": {
 			executable: "flutter",
 			args:       []string{"--version"},
 			regex:      `Flutter (?P<version>((?P<major>[0-9]+).(?P<minor>[0-9]+).(?P<patch>[0-9]+)))`,
 		},
 	}
+	f.defaultTooling = []string{"fvm", "flutter"}
 	f.versionURLTemplate = "https://github.com/flutter/flutter/releases/tag/{{ .Major }}.{{ .Minor }}.{{ .Patch }}"
 
-	return f.language.Enabled()
+	return f.Language.Enabled()
 }
