@@ -64,13 +64,13 @@ func (n *Node) loadContext() {
 			fileName:     "pnpm-lock.yaml",
 			name:         "pnpm",
 			iconProperty: PnpmIcon,
-			defaultIcon:  "\U000F02C1",
+			defaultIcon:  "\ue865",
 		},
 		{
 			fileName:     "yarn.lock",
 			name:         "yarn",
 			iconProperty: YarnIcon,
-			defaultIcon:  "\U000F011B",
+			defaultIcon:  "\ue6a7",
 		},
 		{
 			fileName:     "bun.lockb",
