@@ -5,9 +5,8 @@ import (
 	"math"
 	"time"
 
-	"github.com/jandedobbeleer/oh-my-posh/src/http"
-	"github.com/jandedobbeleer/oh-my-posh/src/platform"
-	"github.com/jandedobbeleer/oh-my-posh/src/properties"
+	"github.com/jandedobbeleer/oh-my-posh/src/runtime/http"
+	"github.com/jandedobbeleer/oh-my-posh/src/segments/options"
 )
 
 // StravaAPI is a wrapper around http.Oauth
@@ -26,25 +25,24 @@ func (s *stravaAPI) GetActivities() ([]*StravaData, error) {
 
 // segment struct, makes templating easier
 type Strava struct {
-	props properties.Properties
+	Base
 
+	api   StravaAPI
+	Icon  string
+	Ago   string
+	Error string
+	URL   string
 	StravaData
-	Icon         string
-	Ago          string
 	Hours        int
 	Authenticate bool
-	Error        string
-	URL          string
-
-	api StravaAPI
 }
 
 const (
-	RideIcon            properties.Property = "ride_icon"
-	RunIcon             properties.Property = "run_icon"
-	SkiingIcon          properties.Property = "skiing_icon"
-	WorkOutIcon         properties.Property = "workout_icon"
-	UnknownActivityIcon properties.Property = "unknown_activity_icon"
+	RideIcon            options.Option = "ride_icon"
+	RunIcon             options.Option = "run_icon"
+	SkiingIcon          options.Option = "skiing_icon"
+	WorkOutIcon         options.Option = "workout_icon"
+	UnknownActivityIcon options.Option = "unknown_activity_icon"
 
 	StravaAccessTokenKey  = "strava_access_token"
 	StravaRefreshTokenKey = "strava_refresh_token"
@@ -54,18 +52,18 @@ const (
 
 // StravaData struct contains the API data
 type StravaData struct {
-	ID                   int       `json:"id"`
-	Type                 string    `json:"type"`
 	StartDate            time.Time `json:"start_date"`
+	Type                 string    `json:"type"`
 	Name                 string    `json:"name"`
+	ID                   int       `json:"id"`
 	Distance             float64   `json:"distance"`
 	Duration             float64   `json:"moving_time"`
-	DeviceWatts          bool      `json:"device_watts"`
 	AverageWatts         float64   `json:"average_watts"`
 	WeightedAverageWatts float64   `json:"weighted_average_watts"`
 	AverageHeartRate     float64   `json:"average_heartrate"`
 	MaxHeartRate         float64   `json:"max_heartrate"`
 	KudosCount           int       `json:"kudos_count"`
+	DeviceWatts          bool      `json:"device_watts"`
 }
 
 func (s *Strava) Template() string {
@@ -73,6 +71,8 @@ func (s *Strava) Template() string {
 }
 
 func (s *Strava) Enabled() bool {
+	s.initAPI()
+
 	data, err := s.api.GetActivities()
 	if err == nil && len(data) > 0 {
 		s.StravaData = *data[0]
@@ -93,6 +93,28 @@ func (s *Strava) Enabled() bool {
 	return false
 }
 
+func (s *Strava) initAPI() {
+	if s.api != nil {
+		return
+	}
+
+	oauth := &http.OAuthRequest{
+		AccessTokenKey:  StravaAccessTokenKey,
+		RefreshTokenKey: StravaRefreshTokenKey,
+		SegmentName:     "strava",
+		AccessToken:     s.options.String(options.AccessToken, ""),
+		RefreshToken:    s.options.String(options.RefreshToken, ""),
+		Request: http.Request{
+			Env:         s.env,
+			HTTPTimeout: s.options.Int(options.HTTPTimeout, options.DefaultHTTPTimeout),
+		},
+	}
+
+	s.api = &stravaAPI{
+		OAuthRequest: *oauth,
+	}
+}
+
 func (s *Strava) getHours() int {
 	hours := time.Since(s.StartDate).Hours()
 	return int(math.Floor(hours))
@@ -111,32 +133,17 @@ func (s *Strava) getActivityIcon() string {
 	case "VirtualRide":
 		fallthrough
 	case "Ride":
-		return s.props.GetString(RideIcon, "\uf5a2")
+		return s.options.String(RideIcon, "\uf206")
 	case "Run":
-		return s.props.GetString(RunIcon, "\ufc0c")
+		return s.options.String(RunIcon, "\ue213")
 	case "NordicSki":
 	case "AlpineSki":
 	case "BackcountrySki":
-		return s.props.GetString(SkiingIcon, "\ue213")
+		return s.options.String(SkiingIcon, "\ue213")
 	case "WorkOut":
-		return s.props.GetString(WorkOutIcon, "\ue213")
+		return s.options.String(WorkOutIcon, "\ue213")
 	default:
-		return s.props.GetString(UnknownActivityIcon, "\ue213")
-	}
-	return s.props.GetString(UnknownActivityIcon, "\ue213")
-}
-
-func (s *Strava) Init(props properties.Properties, env platform.Environment) {
-	s.props = props
-
-	oauth := &http.OAuthRequest{
-		AccessTokenKey:  StravaAccessTokenKey,
-		RefreshTokenKey: StravaRefreshTokenKey,
-		SegmentName:     "strava",
-	}
-	oauth.Init(env, props)
-
-	s.api = &stravaAPI{
-		OAuthRequest: *oauth,
+		return s.options.String(UnknownActivityIcon, "\ue213")
 	}
+	return s.options.String(UnknownActivityIcon, "\ue213")
 }
