@@ -1,8 +1,6 @@
-const path = require('path');
-
-module.exports = {
+export default {
   title: 'Oh My Posh',
-  tagline: 'A prompt theme engine for any shell.',
+  tagline: 'The most customizable and fastest prompt engine for any shell.',
   url: 'https://ohmyposh.dev',
   baseUrl: '/',
   favicon: 'img/favicons.svg',
@@ -10,8 +8,7 @@ module.exports = {
   projectName: 'oh-my-posh',
   onBrokenLinks: 'ignore',
   plugins: [
-    path.resolve(__dirname, 'plugins', 'appinsights'),
-    'docusaurus-node-polyfills'
+    './plugins/appinsights'
   ],
   stylesheets: [
     "https://rsms.me/inter/inter.css",
@@ -24,7 +21,7 @@ module.exports = {
       respectPrefersColorScheme: true,
     },
     prism: {
-      additionalLanguages: ['powershell', 'lua', 'jsstacktrace', 'toml', 'json', 'yaml'],
+      additionalLanguages: ['powershell', 'lua', 'jsstacktrace', 'toml', 'json'],
     },
     docs: {
         sidebar: {
@@ -57,7 +54,7 @@ module.exports = {
         },
         {
           href: 'https://polar.sh/oh-my-posh',
-          label: 'Buy',
+          label: 'Subscribe',
           position: 'left',
         },
         {
@@ -71,12 +68,6 @@ module.exports = {
           'aria-label': 'GitHub repository',
           position: 'right',
         },
-        {
-          href: 'https://www.warp.dev/oh-my-posh',
-          className: 'header-affiliate-link',
-          'aria-label': 'Warp',
-          position: 'right',
-        },
         {
           href: 'https://discord.gg/n7E3DkXssv',
           className: 'header-discord-link',
@@ -132,13 +123,9 @@ module.exports = {
               href: 'https://github.com/sponsors/JanDeDobbeleer',
             },
             {
-              label: 'Buy',
+              label: 'Subscribe',
               href: 'https://polar.sh/oh-my-posh',
             },
-            {
-              label: 'Warp',
-              href: 'https://www.warp.dev/oh-my-posh',
-            },
             {
               label: 'Docusaurus',
               href: 'https://github.com/facebook/docusaurus',
@@ -148,6 +135,15 @@ module.exports = {
               href: '/privacy',
             },
           ],
+        },
+                {
+          title: 'Sponsors',
+          items: [
+            {
+              label: 'Merge Conflict',
+              href: 'https://www.mergeconflict.fm/',
+            },
+          ],
         },
       ],
       copyright: `Copyright © ${new Date().getFullYear()} <a href='https://github.com/sponsors/JanDeDobbeleer' target='_blank'>Jan De Dobbeleer</a> and <a href='/docs/contributors'>contributors</a>.`,
@@ -174,13 +170,13 @@ module.exports = {
       '@docusaurus/preset-classic',
       {
         docs: {
-          sidebarPath: require.resolve('./sidebars.js'),
+          sidebarPath: './sidebars.js',
           editUrl: 'https://github.com/jandedobbeleer/oh-my-posh/edit/main/website/',
         },
         theme: {
           customCss: [
-            require.resolve('./src/css/prism-rose-pine-moon.css'),
-            require.resolve('./src/css/custom.css')
+            './src/css/prism-rose-pine-moon.css',
+            './src/css/custom.css'
           ],
         },
         blog: {
